## List all your folders

### Request
```
GET /folder/list
```

#### Form Data
| Attribute | Description |
| ------ | ------ |
| `Token` |  Need to provide the token which generated during the login |
##### Note:  Need to provide token under authorization as Bearer token


### Response
There are 2 types of responses.
| Status Code | Description |
| ------ | ------ |
| 200 | It will return the values as json data and list data one by one. |
| 400 | Bad Request Format or The user is not authenticated. |

#### Examples
##### 200 OK
```
{
    "id": "1"
    "name": "lahtp notes"
    "owner": "lahtp"
    "created_at": "1 hour ago"
     
    "id": "2"
    "name": "lahtp notes2"
    "owner": "lahtp2"
    "created_at": "1 hour ago"
}
```
##### 400 Bad Request
```
{
    "error": "Bad request"
}
```

## Create a new folder
### Request
```
  POST /folder/new
  Authorization: Bearer <your_access_token>
```

#### Form Data
| Attribute | Description |
| ------ | ------ |
| `Token` | Need to provide the token which generated during the login |
| `Name`  | Need to provide the name of the folder. |

### Response
There are 3 types of responses.
| Status Code | Description |
| ------ | ------ |
| 200 | Folder created successfully. |
| 403 | unauthorized user. |
| 400 | Bad Request Format or Not all attributes are available. |


#### Examples
##### 200 OK
```
{
    "folder_id": 13
}
```
##### 400 Bad Request
```
{
    "error": "Bad request"
}
```

## Get all notes

### Request
```
POST /folder/get_all_notes
Authorization: Bearer <your_access_token>
```

#### Form Data
| Attribute | Description |
| ------ | ------ |
| `Token` | Need to provide the token generated during login |

### Response
There are 3 types of responses.
| Status Code | Description |
| ------ | ------ |
| 200 | success it will list all the notes |
| 403 | unauthorized user. |
| 400 | Bad Request Format or Not all attributes are available. |


#### Examples
##### 200 OK
```
{
    "count": "2",
    "notes": [
          "id": "1"
          "name": "lahtp notes"
          "owner": "lahtp"
          "created_at": "1 day ago"
          "modified_at": "1 hour ago"

          "id": "2"
          "name": "lahtp notes 2"
          "owner": "lahtp"
          "created_at": "1 day ago"
          "modified_at": "1 hour ago"


]
}
   
```
##### 400 Bad Request
```
{
    "error": "Bad request"
}
```

## Delete note

### Request
```
POST /auth/delete
Authorization: Bearer <your_access_token>
```

#### Form Data
| Attribute | Description |
| ------ | ------ |
| `Note_search_Term` | Need of particular folder Id (or) Title (or) Body |
| `Token` | Need to provide the token generated during login |

### Response
There are 3 types of responses.
| Status Code | Description |
| ------ | ------ |
| 200 | success data deleted. |
| 403 | unauthorized user. |
| 400 | Bad Request Format . |


#### Examples
##### 200 OK
```
{
    "message": "success"
}
```
##### 400 Bad Request
```
{
    "error": "Bad request"
}
```

## list 

### Request
```
GET /folder/get
Authorization: Bearer <your_access_token>
```

#### Form Data
| Attribute | Description |
| ------ | ------ |
| `id`    | need to provide the id of particular folder      |
| `Token` | Need to provide the token generated during login |

### Response
There are 3 types of responses.
| Status Code | Description |
| ------ | ------ |
| 200 | User can modify the existing data. |
| 403 | unauthorized user. |
| 400 | Bad Request Format . |


#### Examples
##### 200 OK
```
{[
    {
        "id": "12",
        "name": "Default Folder",
        "owner": "lahtp",
        "created_at": "2021-05-19 23:48:22",
        "created": "18 minutes ago",
        "count": "0"
    },
    {
        "id": "13",
        "name": "Personal Notes",
        "owner": "lahtp",
        "created_at": "2021-05-19 23:49:14",
        "created": "18 minutes ago",
        "count": "0"
    },
    {
        "id": "14",
        "name": "Personal Notes",
        "owner": "lahtp",
        "created_at": "2021-05-20 00:05:45",
        "created": "1 minute ago",
        "count": "0"
    }
]
  
}
```
##### 400 Bad Request
```
{
    "error": "Bad request"
}
```


## Rename

### Request
```
post /Folder/rename
Authorization: Bearer <your_access_token>
```

#### Form Data
| Attribute | Description |
| ------ | ------ |
| `id`    | need to provide the id of particular folder      |
| `Token` | Need to provide the token generated during login |

### Response
There are 3 types of responses.
| Status Code | Description |
| ------ | ------ |
| 200 | User can modify the existing data. |
| 403 | unauthorized user. |
| 400 | Bad Request Format . |


#### Examples
##### 200 OK
```
{

    "id": "1"
    "name": "lahtp notes"
    "owner": "lahtp"
    "created_at": "1 day ago"
    "modified_at": "1 hour ago"

 }
```
##### 400 Bad Request
```
{
    "error": "Bad request"
}
```

## Delete

### Request
```
post /Folder/delete
Authorization: Bearer <your_access_token>
```

#### Form Data
| Attribute | Description |
| ------ | ------ |
| `id`    | need to provide the id of particular folder      |
| `Token` | Need to provide the token generated during login |

### Response
There are 3 types of responses.
| Status Code | Description |
| ------ | ------ |
| 200 | operation successful |
| 403 | unauthorized user. |
| 400 | Bad Request Format . |


#### Examples
##### 200 OK
```
{
  "message": "success"
 }
```
##### 400 Bad Request
```
{
    "error": "Bad request"
}
```